@@ -2,6 +2,14 @@ import warnings
 from datetime import date
 from typing import Any, Optional, Sequence, TYPE_CHECKING, Union
 
+from calcbench.api_query_params import (
+    CompanyIdentifierScheme,
+    CompanyIdentifiers,
+    Period,
+    PeriodArgument,
+    PeriodType,
+)
+
 if TYPE_CHECKING:
     # https://github.com/microsoft/pyright/issues/1358
     from typing import TypedDict
@@ -13,11 +21,6 @@ else:
 
 
 from calcbench.api_client import (
-    CompanyIdentifierScheme,
-    CompanyIdentifiers,
-    Period,
-    PeriodArgument,
-    PeriodType,
     _json_POST,
     logger,
 )
@@ -59,7 +62,7 @@ class StandardizedPoint(TypedDict):
     ticker: str
     calcbench_entity_id: int
     filing_type: str  # 10-K, 10-Q, 8-K, PRESSRELEASE, etc.
-    is_preliminary_data: bool
+    preliminary: bool
     CIK: str
     trace_url: Optional[str]
     period: Any  # pandas period
@@ -264,7 +267,6 @@ def point_in_time(
 
     Standardized data with a timestamp when it was published by Calcbench
 
-    :param update_date: The date on which the data was received, this does not work prior to ~2016, use all_history to get historical data then use update_date to get updates.
     :param accession_id: Unique identifier for the filing for which to recieve data.  Pass this to recieve data for one filing.  Same as filing_id in filings objects
     :param all_face: Retrieve all of the points from the face financials, income/balance/statement of cash flows
     :param all_footnotes: Retrive all of the points from the footnotes to the financials
@@ -398,7 +400,7 @@ def point_in_time(
                     year=data.fiscal_year, quarter=data.fiscal_period, freq="Q"
                 )
             elif period_type == PeriodType.Annual:
-                data["period"] = data["fiscal_year"]
+                data["period"] = pd.PeriodIndex(data["fiscal_year"], freq="A")
         data.drop(["fiscal_year", "fiscal_period"], axis=1, inplace=True)
         data = data.set_index(["ticker", "metric", "period", "revision_number"])
     else:
@@ -511,9 +513,13 @@ def standardized_data(
     if missing_metrics:
         warnings.warn("Did not find metrics {0}".format(missing_metrics))
     data = pd.DataFrame(data)
+    for column in ["metric", "ticker", "CIK"]:
+        data[column] = pd.Categorical(data[column])  # type: ignore
+
     data.set_index(
         keys=[f"{company_identifier_scheme}", "metric", "period"], inplace=True  # type: ignore
     )  # type: ignore
+
     try:
         data = data.unstack("metric")  # type: ignore
     except ValueError as e:
@@ -522,6 +528,7 @@ def standardized_data(
             logger.error("Duplicate values \n {0}".format(duplicates))
         raise
     data = data["value"]
+
     for column_name in data.columns.values:
         # Try to make the columns the right type
         try:
